Module beamlit.models.account
=============================

Classes
-------

`Account(created_at: beamlit.types.Unset | str = <beamlit.types.Unset object>, updated_at: beamlit.types.Unset | str = <beamlit.types.Unset object>, created_by: beamlit.types.Unset | str = <beamlit.types.Unset object>, updated_by: beamlit.types.Unset | str = <beamlit.types.Unset object>, display_name: beamlit.types.Unset | str = <beamlit.types.Unset object>, labels: beamlit.types.Unset | ForwardRef('MetadataLabels') = <beamlit.types.Unset object>, name: beamlit.types.Unset | str = <beamlit.types.Unset object>, workspace: beamlit.types.Unset | str = <beamlit.types.Unset object>, address: beamlit.types.Unset | ForwardRef('AccountSpecAddress') = <beamlit.types.Unset object>, admins: beamlit.types.Unset | list[typing.Any] = <beamlit.types.Unset object>, currency: beamlit.types.Unset | str = <beamlit.types.Unset object>, owner: beamlit.types.Unset | str = <beamlit.types.Unset object>, status: beamlit.types.Unset | str = <beamlit.types.Unset object>, tax_id: beamlit.types.Unset | str = <beamlit.types.Unset object>, metadata: beamlit.types.Unset | Any = <beamlit.types.Unset object>, spec: beamlit.types.Unset | Any = <beamlit.types.Unset object>)`
:   Account
    
    Attributes:
        created_at (Union[Unset, str]): The date and time when the resource was created
        updated_at (Union[Unset, str]): The date and time when the resource was updated
        created_by (Union[Unset, str]): The user or service account who created the resource
        updated_by (Union[Unset, str]): The user or service account who updated the resource
        display_name (Union[Unset, str]): Model display name
        labels (Union[Unset, MetadataLabels]): Labels
        name (Union[Unset, str]): Model name
        workspace (Union[Unset, str]): Workspace name
        address (Union[Unset, AccountSpecAddress]): Billing address
        admins (Union[Unset, list[Any]]): Admins
        currency (Union[Unset, str]): Currency
        owner (Union[Unset, str]): Owner
        status (Union[Unset, str]): Status
        tax_id (Union[Unset, str]): Tax ID
        metadata (Union[Unset, Any]):
        spec (Union[Unset, Any]):
    
    Method generated by attrs for class Account.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `address`
    :

    `admins`
    :

    `created_at`
    :

    `created_by`
    :

    `currency`
    :

    `display_name`
    :

    `labels`
    :

    `metadata`
    :

    `name`
    :

    `owner`
    :

    `spec`
    :

    `status`
    :

    `tax_id`
    :

    `updated_at`
    :

    `updated_by`
    :

    `workspace`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :